macro_rules! print_debugging {
($($arg:tt)*) => { ... };
}Expand description
Print debugging to the standard error only in debug build.
It is easy to find where is used, because of the special name.
The tracing debug is not for the same purpose.